==> chaosmesh-model-6.8.1-sources.jar: io/fabric8/chaosmesh/v1alpha1/JVMStressSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class JVMStressSpecFluent<A extends JVMStressSpecFluent<A>> extends BaseFluent<A>{
  public JVMStressSpecFluent() {
  }
  public JVMStressSpecFluent(JVMStressSpec instance) {
    instance = (instance != null ? instance : new JVMStressSpec());

    if (instance != null) {
      this.withCpuCount(instance.getCpuCount());
      this.withMemType(instance.getMemType());
      this.withPid(instance.getPid());
      this.withPort(instance.getPort());
      this.withCpuCount(instance.getCpuCount());
      this.withMemType(instance.getMemType());
      this.withPid(instance.getPid());
      this.withPort(instance.getPort());
    }
  }
  private Integer cpuCount;
  private String memType;
  private Integer pid;
  private Integer port;
  public Integer getCpuCount() {
    return this.cpuCount;
  }
  public A withCpuCount(Integer cpuCount) {
    this.cpuCount=cpuCount; return (A) this;
  }
  public boolean hasCpuCount() {
    return this.cpuCount != null;
  }
  public String getMemType() {
    return this.memType;
  }
  public A withMemType(String memType) {
    this.memType=memType; return (A) this;
  }
  public boolean hasMemType() {
    return this.memType != null;
  }
  public Integer getPid() {
    return this.pid;
  }
  public A withPid(Integer pid) {
    this.pid=pid; return (A) this;
  }
  public boolean hasPid() {
    return this.pid != null;
  }
  public Integer getPort() {
    return this.port;
  }
  public A withPort(Integer port) {
    this.port=port; return (A) this;
  }
  public boolean hasPort() {
    return this.port != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    JVMStressSpecFluent that = (JVMStressSpecFluent) o;
    if (!java.util.Objects.equals(cpuCount, that.cpuCount)) return false;

    if (!java.util.Objects.equals(memType, that.memType)) return false;

    if (!java.util.Objects.equals(pid, that.pid)) return false;

    if (!java.util.Objects.equals(port, that.port)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(cpuCount,  memType,  pid,  port,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (cpuCount != null) { sb.append("cpuCount:"); sb.append(cpuCount + ","); }
    if (memType != null) { sb.append("memType:"); sb.append(memType + ","); }
    if (pid != null) { sb.append("pid:"); sb.append(pid + ","); }
    if (port != null) { sb.append("port:"); sb.append(port); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> chaosmesh-model-6.9.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/JVMStressSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class JVMStressSpecFluent<A extends JVMStressSpecFluent<A>> extends BaseFluent<A>{
  public JVMStressSpecFluent() {
  }
  
  public JVMStressSpecFluent(JVMStressSpec instance) {
    this.copyInstance(instance);
  }
  private Integer cpuCount;
  private String memType;
  private Integer pid;
  private Integer port;
  
  protected void copyInstance(JVMStressSpec instance) {
    instance = (instance != null ? instance : new JVMStressSpec());
  
    if (instance != null) {
        this.withCpuCount(instance.getCpuCount());
        this.withMemType(instance.getMemType());
        this.withPid(instance.getPid());
        this.withPort(instance.getPort());
        this.withCpuCount(instance.getCpuCount());
        this.withMemType(instance.getMemType());
        this.withPid(instance.getPid());
        this.withPort(instance.getPort());
      }
  }
  
  public Integer getCpuCount() {
    return this.cpuCount;
  }
  
  public A withCpuCount(Integer cpuCount) {
    this.cpuCount=cpuCount; return (A) this;
  }
  
  public boolean hasCpuCount() {
    return this.cpuCount != null;
  }
  
  public String getMemType() {
    return this.memType;
  }
  
  public A withMemType(String memType) {
    this.memType=memType; return (A) this;
  }
  
  public boolean hasMemType() {
    return this.memType != null;
  }
  
  public Integer getPid() {
    return this.pid;
  }
  
  public A withPid(Integer pid) {
    this.pid=pid; return (A) this;
  }
  
  public boolean hasPid() {
    return this.pid != null;
  }
  
  public Integer getPort() {
    return this.port;
  }
  
  public A withPort(Integer port) {
    this.port=port; return (A) this;
  }
  
  public boolean hasPort() {
    return this.port != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    JVMStressSpecFluent that = (JVMStressSpecFluent) o;
    if (!java.util.Objects.equals(cpuCount, that.cpuCount)) return false;
  
    if (!java.util.Objects.equals(memType, that.memType)) return false;
  
    if (!java.util.Objects.equals(pid, that.pid)) return false;
  
    if (!java.util.Objects.equals(port, that.port)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(cpuCount,  memType,  pid,  port,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (cpuCount != null) { sb.append("cpuCount:"); sb.append(cpuCount + ","); }
    if (memType != null) { sb.append("memType:"); sb.append(memType + ","); }
    if (pid != null) { sb.append("pid:"); sb.append(pid + ","); }
    if (port != null) { sb.append("port:"); sb.append(port); }
    sb.append("}");
    return sb.toString();
  }
  

}
